import"./vue-router.d9feb5a3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},x=new Error().stack;x&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[x]="bed84315-bacd-4e5e-a172-832bbe5e7c54",e._sentryDebugIdIdentifier="sentry-dbid-bed84315-bacd-4e5e-a172-832bbe5e7c54")}catch{}})();const d=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(e){const x=Math.random()*16|0;return(e=="x"?x:x&3|8).toString(16)});export{d as u};
//# sourceMappingURL=uuid.dddf5724.js.map
