import{C as y}from"./ContentLayout.da179fcc.js";import{d as w,L as c,N as l,e as g,c as a,w as f,o as i,b as n,u as o,R as s}from"./vue-router.d9feb5a3.js";import{K as _,_ as v,W as K,E as R,a as E}from"./WorkflowView.799a3391.js";import{E as T}from"./api.4e2ade5f.js";import{A as p,T as V}from"./TabPane.51d9ffdd.js";import"./fetch.5f113e8c.js";import"./linters.2e55d4ab.js";import"./asyncComputed.5aa790b6.js";import"./scripts.54429eee.js";import"./record.6cf0986e.js";import"./metadata.12a669c4.js";import"./PhBug.vue.2d3a598b.js";import"./PhCheckCircle.vue.e597d3cd.js";import"./PhKanban.vue.909e89e7.js";import"./PhWebhooksLogo.vue.208982f2.js";import"./PhQuestion.vue.4b4fbff5.js";import"./ant-design.02104fdb.js";import"./index.3ceffa89.js";import"./index.ecae1a65.js";import"./index.c9d929b5.js";import"./CollapsePanel.8d814875.js";import"./index.30e709aa.js";import"./index.78acb2c7.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.67412665.js";import"./model.f7c11cdc.js";import"./workspaces.f6b6ff86.js";import"./workspaceStore.012827c9.js";import"./url.99c6614b.js";import"./validations.e3661f0e.js";import"./string.c0b64362.js";import"./PhArrowSquareOut.vue.1c53182b.js";import"./index.7a12ec38.js";import"./Badge.82a04824.js";import"./index.2bcec40e.js";import"./Card.afa2cbc4.js";import"./uuid.dddf5724.js";import"./LoadingOutlined.af5d4d4b.js";import"./DeleteOutlined.4ba4b21e.js";import"./PhDownloadSimple.vue.d5cc6d29.js";import"./utils.77984e10.js";import"./LoadingContainer.56c3fdb1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0c547155-ffb5-4d4e-ae20-2d7eb5a1a25c",e._sentryDebugIdIdentifier="sentry-dbid-0c547155-ffb5-4d4e-ae20-2d7eb5a1a25c")}catch{}})();const wo=w({__name:"WorkflowThreads",setup(e){const t=new R,m=new E,d=new c(l.array(l.string()),"kanban-selected-stages"),u=new T,r=g("kanban");return(W,b)=>(i(),a(y,{"full-width":""},{default:f(()=>[n(o(V),{activeKey:r.value,"onUpdate:activeKey":b[0]||(b[0]=k=>r.value=k)},{default:f(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),r.value==="kanban"?(i(),a(_,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(d),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),r.value==="table"?(i(),a(v,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),r.value==="workflow"?(i(),a(K,{key:2,"kanban-repository":o(t),"workflow-api":o(u)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{wo as default};
//# sourceMappingURL=WorkflowThreads.f473737e.js.map
