import{d as i,c as n,w as p,o as s,b as a,u as e}from"./vue-router.d9feb5a3.js";import"./linters.2e55d4ab.js";import{W as m}from"./workspaces.f6b6ff86.js";import{C as d}from"./ContentLayout.da179fcc.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.a8d0bb80.js";import"./asyncComputed.5aa790b6.js";import"./workspaceStore.012827c9.js";import"./url.99c6614b.js";import"./record.6cf0986e.js";import"./gateway.bcb6c1cd.js";import"./popupNotifcation.326ad4ba.js";import"./fetch.5f113e8c.js";import"./SaveButton.26e3146d.js";import"./ExclamationCircleOutlined.3e6cd53f.js";import"./CrudView.00ba8ddf.js";import"./router.3320320c.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.7780e068.js";import"./BookOutlined.06277ca0.js";import"./PhDotsThreeVertical.vue.83d724ac.js";import"./index.3ceffa89.js";import"./PhRocketLaunch.vue.6ba91364.js";import"./PhPencil.vue.7afad853.js";import"./index.2bcec40e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="33210492-c204-4654-8ab7-8bdc6f69e407",o._sentryDebugIdIdentifier="sentry-dbid-33210492-c204-4654-8ab7-8bdc6f69e407")}catch{}})();const q=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(t,u)=>(s(),n(d,null,{default:p(()=>[a(f,{"env-var-repository":e(r),mode:"editor","file-opender":e(m)},null,8,["env-var-repository","file-opender"])]),_:1}))}});export{q as default};
//# sourceMappingURL=EnvVarsEditor.f7540ec0.js.map
