import{d as n,W as s,a,Z as d,e4 as r,o as l,$ as c}from"./vue-router.d9feb5a3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="58f814ec-7b1c-4570-9247-12d8f64aa923",e._sentryDebugIdIdentifier="sentry-dbid-58f814ec-7b1c-4570-9247-12d8f64aa923")}catch{}})();const _={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(l(),s("div",_,[a("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[d(t.$slots,"default",{},void 0,!0)],2)]))}});const i=c(u,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.da179fcc.js.map
