import{_ as c}from"./Login.vue_vue_type_script_setup_true_lang.96bcd9d2.js";import{a as d}from"./workspaceStore.012827c9.js";import{d as _,ek as f,e7 as i,W as u,b as p,o as m,$ as y}from"./vue-router.d9feb5a3.js";import"./CircularLoading.12085bfa.js";import"./index.2bcec40e.js";import"./url.99c6614b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2a17cf39-4d06-46bf-9448-fc10d4007d91",e._sentryDebugIdIdentifier="sentry-dbid-2a17cf39-4d06-46bf-9448-fc10d4007d91")}catch{}})();const l={class:"runner"},b=_({__name:"Login",setup(e){const t=f(),o=i(),r=d(),a=async()=>{await r.signUp();const{redirect:s,...n}=o.query;if(s){await t.push({path:s,query:n,params:o.params});return}t.push({name:"playerHome",query:n})};return(s,n)=>(m(),u("div",l,[p(c,{onDone:a})]))}});const k=y(b,[["__scopeId","data-v-5b8c1f5f"]]);export{k as default};
//# sourceMappingURL=Login.01bdd397.js.map
