import{ew as n,ex as t}from"./vue-router.d9feb5a3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="2ade6aee-fe82-4dc3-9b86-97efebf63fd0",e._sentryDebugIdIdentifier="sentry-dbid-2ade6aee-fe82-4dc3-9b86-97efebf63fd0")}catch{}})();function a(e,f){return n(1,arguments),t(e,Date.now(),f)}export{a as f};
//# sourceMappingURL=index.ecae1a65.js.map
