import{O as r}from"./workspaceStore.012827c9.js";import{d as l,V as i,W as u,b as a,w as n,u as d,o as c,ax as o,d5 as f,d4 as b}from"./vue-router.d9feb5a3.js";import"./url.99c6614b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="bdd3f367-5a3f-41ea-b7b0-537d425d69eb",e._sentryDebugIdIdentifier="sentry-dbid-bdd3f367-5a3f-41ea-b7b0-537d425d69eb")}catch{}})();const m=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(t,s)=>(c(),u("div",null,[a(d(f),null,{default:n(()=>[o("You're authenticated")]),_:1}),a(d(b),null,{default:n(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{m as default};
//# sourceMappingURL=OidcLoginCallback.b2ee8178.js.map
