import{d as r,o,c as d,w as a,b as u,Z as f,u as s,d9 as i,eQ as l,eR as c,bL as p}from"./vue-router.d9feb5a3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5006a483-3300-427d-a8bb-679920ea0410",e._sentryDebugIdIdentifier="sentry-dbid-5006a483-3300-427d-a8bb-679920ea0410")}catch{}})();const _=r({__name:"AbstraButton",setup(e){return(t,n)=>(o(),d(s(p),l(c(t.$attrs)),{default:a(()=>[u(s(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[f(t.$slots,"default")]),_:3})]),_:3},16))}});export{_};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.6c824560.js.map
