import{d as p,f as l,o as n,W as o,a,aJ as r,e9 as d,e4 as f,e6 as _,R as i,$ as u}from"./vue-router.d9feb5a3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="715e4b3e-f951-4e16-9dd2-9b97c5474fb3",e._sentryDebugIdIdentifier="sentry-dbid-715e4b3e-f951-4e16-9dd2-9b97c5474fb3")}catch{}})();const m={key:0,class:"p-steps p-component"},b={class:"p-steps-list"},y={class:"p-menuitem-link"},g={class:"p-steps-number"},I=p({__name:"Steps",props:{stepsInfo:{type:Object,default:null}},setup(e){const s=e,c=l(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",to:""})):[]);return(h,k)=>e.stepsInfo?(n(),o("nav",m,[a("ol",b,[(n(!0),o(r,null,d(c.value,(v,t)=>(n(),o("li",{key:t,class:f(["p-steps-item",{"p-highlight":t+1===e.stepsInfo.current}])},[a("span",y,[a("span",g,_(t+1),1)])],2))),128))])])):i("",!0)}});const D=u(I,[["__scopeId","data-v-c916ecf3"]]);export{D as S};
//# sourceMappingURL=Steps.163673cd.js.map
