import{d as t,o,W as s,b as d,u as f,bp as r,$ as _}from"./vue-router.d9feb5a3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="863b9c6f-3fbf-4a7c-a3af-2e2a127fb23f",e._sentryDebugIdIdentifier="sentry-dbid-863b9c6f-3fbf-4a7c-a3af-2e2a127fb23f")}catch{}})();const c={class:"centered"},i=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",c,[d(f(r))]))}});const b=_(i,[["__scopeId","data-v-52e6209a"]]);export{b as L};
//# sourceMappingURL=LoadingContainer.56c3fdb1.js.map
