.connector-card[data-v-9fe50f51]{cursor:pointer;transition:all .3s;&[data-v-9fe50f51]:hover{box-shadow:0 0 15px #0000001a}}.connectors-grid[data-v-46320a53]{display:grid;grid-template-columns:repeat(auto-fill,minmax(300px,1fr));gap:20px}
