import{B as r}from"./BookOutlined.06277ca0.js";import{d as f,o as s,c as l,w as o,b as c,u as d,Z as u,W as i,ax as p,aJ as b,bL as y}from"./vue-router.d9feb5a3.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="e2f3888a-4721-45f3-be7a-0ad4f6dbddd9",t._sentryDebugIdIdentifier="sentry-dbid-e2f3888a-4721-45f3-be7a-0ad4f6dbddd9")}catch{}})();const g=f({__name:"DocsButton",props:{path:{}},setup(t){return(e,n)=>{var a;return s(),l(d(y),{class:"docs-button",href:`https://docs.abstra.io/${(a=e.path)!=null?a:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[c(d(r))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(s(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.7780e068.js.map
