[data-v-0a23904b]:root{--main-font-family: DM Sans, sans-serif}[data-v-0a23904b]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-0a23904b]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-0a23904b]{background-color:#fff;padding:10px}.form[data-v-0a23904b]{align-items:center;justify-content:center;background-color:#fff;width:400px;box-shadow:0 4px 8px #0000001a;gap:10px;border-radius:8px;padding:40px 80px;font-family:DM Sans,sans-serif}.form .header[data-v-0a23904b]{display:flex;flex-direction:column;align-items:center;gap:10px;margin:0 0 50px}.form .header h2[data-v-0a23904b]{font-size:24px;font-weight:500;padding:0;margin:0;font-family:DM Sans,sans-serif}.form .section[data-v-0a23904b]{display:flex;flex-direction:column;gap:20px}.form .section .description[data-v-0a23904b]{font-size:16px;font-weight:400;text-align:center}.form .section .footer[data-v-0a23904b]{font-size:14px;font-weight:400;text-align:center}.loading[data-v-0a23904b]{display:flex;justify-content:center}.passwordless[data-v-e4e9b925]{display:flex;align-items:center}.login[data-v-e4e9b925]{display:flex;align-items:center;justify-content:center;height:100vh}.loading[data-v-e4e9b925]{display:flex;justify-content:center;align-items:center;height:100vh}
