import{a as k}from"./workspaceStore.012827c9.js";import{d as _,L as w,N as c,e as g,W as v,b as a,w as h,u as e,c as p,R as m,o as s,$ as T}from"./vue-router.d9feb5a3.js";import{K,_ as R,W as I,P,b as S}from"./WorkflowView.799a3391.js";import{P as V}from"./api.4e2ade5f.js";import{A as l,T as W}from"./TabPane.51d9ffdd.js";import"./Card.afa2cbc4.js";import"./url.99c6614b.js";import"./fetch.5f113e8c.js";import"./linters.2e55d4ab.js";import"./asyncComputed.5aa790b6.js";import"./scripts.54429eee.js";import"./record.6cf0986e.js";import"./metadata.12a669c4.js";import"./PhBug.vue.2d3a598b.js";import"./PhCheckCircle.vue.e597d3cd.js";import"./PhKanban.vue.909e89e7.js";import"./PhWebhooksLogo.vue.208982f2.js";import"./PhQuestion.vue.4b4fbff5.js";import"./ant-design.02104fdb.js";import"./index.3ceffa89.js";import"./index.ecae1a65.js";import"./index.c9d929b5.js";import"./CollapsePanel.8d814875.js";import"./index.30e709aa.js";import"./index.78acb2c7.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.67412665.js";import"./model.f7c11cdc.js";import"./workspaces.f6b6ff86.js";import"./validations.e3661f0e.js";import"./string.c0b64362.js";import"./PhArrowSquareOut.vue.1c53182b.js";import"./index.7a12ec38.js";import"./Badge.82a04824.js";import"./index.2bcec40e.js";import"./uuid.dddf5724.js";import"./LoadingOutlined.af5d4d4b.js";import"./DeleteOutlined.4ba4b21e.js";import"./PhDownloadSimple.vue.d5cc6d29.js";import"./utils.77984e10.js";import"./LoadingContainer.56c3fdb1.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="86616280-b771-49d5-bfed-c614e8c12869",t._sentryDebugIdIdentifier="sentry-dbid-86616280-b771-49d5-bfed-c614e8c12869")}catch{}})();const x={class:"threads-view"},A=_({__name:"Threads",setup(t){const r=k().authHeaders,d=new V(r),i=new P(r),u=new S(r),y=new w(c.array(c.string()),"kanban-selected-stages"),o=g("kanban");return(B,b)=>(s(),v("div",x,[a(e(W),{activeKey:o.value,"onUpdate:activeKey":b[0]||(b[0]=f=>o.value=f)},{default:h(()=>[a(e(l),{key:"kanban",tab:"Kanban View"}),a(e(l),{key:"table",tab:"Table View"}),a(e(l),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(s(),p(K,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(y),"stage-run-repository":e(u)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(s(),p(R,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(s(),p(I,{key:2,"kanban-repository":e(i),"workflow-api":e(d)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ve=T(A,[["__scopeId","data-v-86c0b860"]]);export{ve as default};
//# sourceMappingURL=Threads.54528d7a.js.map
