import{b as i,eb as l,ey as u}from"./vue-router.d9feb5a3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="269b56c8-aad3-4238-84c6-8ccff8861843",e._sentryDebugIdIdentifier="sentry-dbid-269b56c8-aad3-4238-84c6-8ccff8861843")}catch{}})();function f(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){d(e,a,n[a])})}return e}function d(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var c=function(t,n){var r=f({},t,n.attrs);return i(l,f({},r,{icon:u}),null)};c.displayName="DeleteOutlined";c.inheritAttrs=!1;const s=c;export{s as D};
//# sourceMappingURL=DeleteOutlined.4ba4b21e.js.map
