import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.a8d0bb80.js";import{d as s,e7 as i,c as a,u as m,o as c}from"./vue-router.d9feb5a3.js";import"./gateway.bcb6c1cd.js";import"./popupNotifcation.326ad4ba.js";import"./fetch.5f113e8c.js";import"./record.6cf0986e.js";import"./SaveButton.26e3146d.js";import"./ExclamationCircleOutlined.3e6cd53f.js";import"./CrudView.00ba8ddf.js";import"./router.3320320c.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.7780e068.js";import"./BookOutlined.06277ca0.js";import"./url.99c6614b.js";import"./PhDotsThreeVertical.vue.83d724ac.js";import"./index.3ceffa89.js";import"./PhRocketLaunch.vue.6ba91364.js";import"./asyncComputed.5aa790b6.js";import"./PhPencil.vue.7afad853.js";import"./index.2bcec40e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="2d2ec076-0cef-4246-947e-12636201af44",o._sentryDebugIdIdentifier="sentry-dbid-2d2ec076-0cef-4246-947e-12636201af44")}catch{}})();const $=s({__name:"EnvVars",setup(o){const r=i().params.projectId,t=new p(r);return(d,f)=>(c(),a(n,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{$ as default};
//# sourceMappingURL=EnvVars.5db0f692.js.map
