import{$ as n,o,W as a,Z as s,a as d,R as r}from"./vue-router.d9feb5a3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="806ca3a8-eb8e-41fc-9878-10d01aa0ad59",e._sentryDebugIdIdentifier="sentry-dbid-806ca3a8-eb8e-41fc-9878-10d01aa0ad59")}catch{}})();const c={},i={class:"base-layout"},f={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),a("div",i,[s(e.$slots,"sidebar",{},void 0,!0),d("section",f,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),a("section",u,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])])}const y=n(c,[["render",_],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.7c01463e.js.map
