import{O as r}from"./workspaceStore.012827c9.js";import{d as l,V as i,W as u,b as t,w as o,u as n,o as c,ax as d,d5 as f,d4 as b}from"./vue-router.d9feb5a3.js";import"./url.99c6614b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a061661a-5f0b-4d4d-ba51-4f92ec56f3ba",e._sentryDebugIdIdentifier="sentry-dbid-a061661a-5f0b-4d4d-ba51-4f92ec56f3ba")}catch{}})();const m=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(a,s)=>(c(),u("div",null,[t(n(f),null,{default:o(()=>[d("You're authenticated")]),_:1}),t(n(b),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{m as default};
//# sourceMappingURL=OidcLogoutCallback.54404794.js.map
